Checks
======

The following is a listing of available checks in geomancy.

.. include:: core/index.rst
    :end-before: .. toctree::

.. include:: aws/index.rst
    :end-before: .. toctree::

.. toctree::
    :maxdepth: 1
    :hidden:
    :glob:

    core/index
    aws/index
